@@ -1,5 +1,5 @@
 package POEx::ZMQ;
-$POEx::ZMQ::VERSION = '0.005003';
+$POEx::ZMQ::VERSION = '0.005004';
 use strictures 1;
 
 use Scalar::Util 'blessed';
@@ -111,12 +111,6 @@ general.
 Each ZeroMQ socket is an event emitter powered by L<MooX::Role::POE::Emitter>;
 the documentation for that distribution is likely to be helpful.
 
-B<This is early-development software,> as indicated by the C<0.x> version number.
-The test suite is incomplete, bugs are sure to be lurking, documentation is
-not yet especially verbose, and the API is not I<completely> guaranteed.  Issues
-& pull requests are welcome, of course:
-L<http://www.github.com/avenj/poex-zmq>
-
 If you are not using L<POE>, try L<ZMQ::FFI> for an excellent loop-agnostic
 ZeroMQ implementation.
 
@@ -178,8 +172,25 @@ L</new> & L</context>.
 
 C<@_> is passed through to the L<POEx::ZMQ::Socket> constructor.
 
+=head1 KNOWN BUGS
+
+Dumps core upon process exit on FreeBSD before C<10.x>. Do not know why and
+have not debugged, but patches welcome? ;-)
+
 =head1 SEE ALSO
 
+L<POEx::ZMQ::Socket>
+
+L<POEx::ZMQ::Constants>
+
+L<POEx::ZMQ::Types>
+
+L<POEx::ZMQ::FFI::Socket>
+
+L<POEx::ZMQ::FFI::Context>
+
+L<POEx::ZMQ::FFI>
+
 L<Text::ZPL> for ZeroMQ Property Language support.
 
 L<Crypt::ZCert> for ZeroMQ4+ CURVE certificate management & key pair
