@@ -1,5 +1,5 @@
 package POEx::ZMQ::FFI::Callable;
-$POEx::ZMQ::FFI::Callable::VERSION = '0.005003';
+$POEx::ZMQ::FFI::Callable::VERSION = '0.005004';
 use Carp ();
 use Scalar::Util ();
 use strictures 1;
@@ -26,8 +26,7 @@ sub can {
   }
   return unless exists $self->{$method};
   sub {
-    my ($self) = @_;
-    if (my $sub = $self->SUPER::can($method)) {
+    if (my $sub = $_[0]->SUPER::can($method)) {
       goto $sub
     }
     $AUTOLOAD = $method;
