@@ -1,5 +1,5 @@
 package POEx::ZMQ::FFI::Socket;
-$POEx::ZMQ::FFI::Socket::VERSION = '0.005003';
+$POEx::ZMQ::FFI::Socket::VERSION = '0.005004';
 use v5.10;
 use Carp;
 use strictures 1;
@@ -76,8 +76,9 @@ sub _build_ffi {
   my ($self) = @_;
   my $soname = $self->soname;
 
-  my $ffi = POEx::ZMQ::FFI::Cached->get(Socket => $soname);
-  return $ffi if defined $ffi;
+  if (my $ffi = POEx::ZMQ::FFI::Cached->get(Socket => $soname)) {
+    return $ffi
+  }
 
   POEx::ZMQ::FFI::Cached->set(
     Socket => $soname => POEx::ZMQ::FFI::Callable->new(
@@ -323,10 +324,8 @@ sub get_sock_opt {
   my ($self, $opt, $type) = @_;
   my ($val, $ptr, $len);
 
-  unless (defined $type) {
-    $type = $self->known_type_for_opt($opt)
-      // confess "No return type specified and none known to us (opt $opt)"
-  }
+  $type //= $self->known_type_for_opt($opt)
+        // confess "No return type specified and none known to us (opt $opt)";
 
   if ($type eq 'binary' || $type eq 'string') {
     $ptr = FFI::Raw::memptr( OPTVAL_MAXLEN );
